"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    application_name: str,
    application_description: str = None,
    inputs: List = None,
    outputs: List = None,
    cloud_watch_logging_options: List = None,
    application_code: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.   Creates an Amazon Kinesis Analytics application. You can configure each application with one streaming source as input, application code to process the input, and up to three destinations where you want Amazon Kinesis Analytics to write the output data from your application. For an overview, see How it Works.  In the input configuration, you map the streaming source to an in-application stream, which you can think of as a constantly updating table. In the mapping, you must provide a schema for the in-application stream and map each data column in the in-application stream to a data element in the streaming source. Your application code is one or more SQL statements that read input data, transform it, and generate output. Your application code can create one or more SQL artifacts like SQL streams or pumps. In the output configuration, you can configure the application to write data from in-application streams created in your applications to up to three destinations.  To read data from your source stream or write data to destination streams, Amazon Kinesis Analytics needs your permissions. You grant these permissions by creating IAM roles. This operation requires permissions to perform the kinesisanalytics:CreateApplication action.   For introductory exercises to create an Amazon Kinesis Analytics application, see Getting Started.

    Args:
        application_name(str): Name of your Amazon Kinesis Analytics application (for example, sample-app).
        application_description(str, optional): Summary description of the application. Defaults to None.
        inputs(List, optional): Use this parameter to configure the application input. You can configure your application to receive input from a single streaming source. In this configuration, you map this streaming source to an in-application stream that is created. Your application code can then query the in-application stream like a table (you can think of it as a constantly updating table). For the streaming source, you provide its Amazon Resource Name (ARN) and format of data on the stream (for example, JSON, CSV, etc.). You also must provide an IAM role that Amazon Kinesis Analytics can assume to read this stream on your behalf. To create the in-application stream, you need to specify a schema to transform your data into a schematized version used in SQL. In the schema, you provide the necessary mapping of the data elements in the streaming source to record columns in the in-app stream. Defaults to None.
        outputs(List, optional): You can configure application output to write data from any of the in-application streams to up to three destinations. These destinations can be Amazon Kinesis streams, Amazon Kinesis Firehose delivery streams, AWS Lambda destinations, or any combination of the three. In the configuration, you specify the in-application stream name, the destination stream or Lambda function Amazon Resource Name (ARN), and the format to use when writing data. You must also provide an IAM role that Amazon Kinesis Analytics can assume to write to the destination stream or Lambda function on your behalf. In the output configuration, you also provide the output stream or Lambda function ARN. For stream destinations, you provide the format of data in the stream (for example, JSON, CSV). You also must provide an IAM role that Amazon Kinesis Analytics can assume to write to the stream or Lambda function on your behalf. Defaults to None.
        cloud_watch_logging_options(List, optional): Use this parameter to configure a CloudWatch log stream to monitor application configuration errors. For more information, see Working with Amazon CloudWatch Logs. Defaults to None.
        application_code(str, optional): One or more SQL statements that read input data, transform it, and generate output. For example, you can write a SQL statement that reads data from one in-application stream, generates a running average of the number of advertisement clicks by vendor, and insert resulting rows in another in-application stream using pumps. For more information about the typical pattern, see Application Code.  You can provide such series of SQL statements, where output of one statement can be used as the input for the next statement. You store intermediate results by creating in-application streams and pumps. Note that the application code must create the streams with names specified in the Outputs. For example, if your Outputs defines output streams named ExampleOutputStream1 and ExampleOutputStream2, then your application code must create these streams. . Defaults to None.
        tags(List, optional): A list of one or more tags to assign to the application. A tag is a key-value pair that identifies an application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is 50. For more information, see Using Tagging. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.init.create(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.init.create application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="create_application",
        op_kwargs={
            "ApplicationName": application_name,
            "ApplicationDescription": application_description,
            "Inputs": inputs,
            "Outputs": outputs,
            "CloudWatchLoggingOptions": cloud_watch_logging_options,
            "ApplicationCode": application_code,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, application_name: str, create_timestamp: str) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Deletes the specified application. Amazon Kinesis Analytics halts application execution and deletes the application, including any application artifacts (such as in-application streams, reference table, and application code). This operation requires permissions to perform the kinesisanalytics:DeleteApplication action.

    Args:
        application_name(str): Name of the Amazon Kinesis Analytics application to delete.
        create_timestamp(str):  You can use the DescribeApplication operation to get this value. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.init.delete(
                ctx, application_name=value, create_timestamp=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.init.delete application_name=value, create_timestamp=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="delete_application",
        op_kwargs={
            "ApplicationName": application_name,
            "CreateTimestamp": create_timestamp,
        },
    )


async def describe(hub, ctx, application_name: str) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Returns information about a specific Amazon Kinesis Analytics application. If you want to retrieve a list of all applications in your account, use the ListApplications operation. This operation requires permissions to perform the kinesisanalytics:DescribeApplication action. You can use DescribeApplication to get the current application versionId, which you need to call other operations such as Update.

    Args:
        application_name(str): Name of the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.init.describe(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.init.describe application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="describe_application",
        op_kwargs={"ApplicationName": application_name},
    )


async def list_all(
    hub, ctx, limit: int = None, exclusive_start_application_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Returns a list of Amazon Kinesis Analytics applications in your account. For each application, the response includes the application name, Amazon Resource Name (ARN), and status. If the response returns the HasMoreApplications value as true, you can send another request by adding the ExclusiveStartApplicationName in the request body, and set the value of this to the last application name from the previous response.  If you want detailed information about a specific application, use DescribeApplication. This operation requires permissions to perform the kinesisanalytics:ListApplications action.

    Args:
        limit(int, optional): Maximum number of applications to list. Defaults to None.
        exclusive_start_application_name(str, optional): Name of the application to start the list with. When using pagination to retrieve the list, you don't need to specify this parameter in the first request. However, in subsequent requests, you add the last application name from the previous response to get the next page of applications. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="list_applications",
        op_kwargs={
            "Limit": limit,
            "ExclusiveStartApplicationName": exclusive_start_application_name,
        },
    )


async def start(hub, ctx, application_name: str, input_configurations: List) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Starts the specified Amazon Kinesis Analytics application. After creating an application, you must exclusively call this operation to start your application. After the application starts, it begins consuming the input data, processes it, and writes the output to the configured destination.  The application status must be READY for you to start an application. You can get the application status in the console or using the DescribeApplication operation. After you start the application, you can stop the application from processing the input by calling the StopApplication operation. This operation requires permissions to perform the kinesisanalytics:StartApplication action.

    Args:
        application_name(str): Name of the application.
        input_configurations(List): Identifies the specific input, by ID, that the application starts consuming. Amazon Kinesis Analytics starts reading the streaming source associated with the input. You can also specify where in the streaming source you want Amazon Kinesis Analytics to start reading.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.init.start(
                ctx, application_name=value, input_configurations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.init.start application_name=value, input_configurations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="start_application",
        op_kwargs={
            "ApplicationName": application_name,
            "InputConfigurations": input_configurations,
        },
    )


async def stop(hub, ctx, application_name: str) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Stops the application from processing input data. You can stop an application only if it is in the running state. You can use the DescribeApplication operation to find the application state. After the application is stopped, Amazon Kinesis Analytics stops reading data from the input, the application stops processing data, and there is no output written to the destination.  This operation requires permissions to perform the kinesisanalytics:StopApplication action.

    Args:
        application_name(str): Name of the running application to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.init.stop(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.init.stop application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="stop_application",
        op_kwargs={"ApplicationName": application_name},
    )


async def update(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    application_update: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Updates an existing Amazon Kinesis Analytics application. Using this API, you can update application code, input configuration, and output configuration.  Note that Amazon Kinesis Analytics updates the CurrentApplicationVersionId each time you update your application.  This operation requires permission for the kinesisanalytics:UpdateApplication action.

    Args:
        application_name(str): Name of the Amazon Kinesis Analytics application to update.
        current_application_version_id(int): The current application version ID. You can use the DescribeApplication operation to get this value.
        application_update(Dict): Describes application updates.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.init.update(
                ctx,
                application_name=value,
                current_application_version_id=value,
                application_update=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.init.update application_name=value, current_application_version_id=value, application_update=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="update_application",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "ApplicationUpdate": application_update,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, client_token: str, quantum_task_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified task.

    Args:
        client_token(str): The client token associated with the request.
        quantum_task_arn(str): The ARN of the task to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.braket.quantum_task.cancel(
                ctx, client_token=value, quantum_task_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.braket.quantum_task.cancel client_token=value, quantum_task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="braket",
        operation="cancel_quantum_task",
        op_kwargs={"clientToken": client_token, "quantumTaskArn": quantum_task_arn},
    )


async def create(
    hub,
    ctx,
    action: str,
    client_token: str,
    device_arn: str,
    output_s3_bucket: str,
    output_s3_key_prefix: str,
    shots: int,
    device_parameters: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a quantum task.

    Args:
        action(str): The action associated with the task.
        client_token(str): The client token associated with the request.
        device_arn(str): The ARN of the device to run the task on.
        device_parameters(str, optional): The parameters for the device to run the task on. Defaults to None.
        output_s3_bucket(str): The S3 bucket to store task result files in.
        output_s3_key_prefix(str): The key prefix for the location in the S3 bucket to store task results in.
        shots(int): The number of shots to use for the task.
        tags(Dict, optional): Tags to be added to the quantum task you're creating. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.braket.quantum_task.create(
                ctx,
                action=value,
                client_token=value,
                device_arn=value,
                output_s3_bucket=value,
                output_s3_key_prefix=value,
                shots=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.braket.quantum_task.create action=value, client_token=value, device_arn=value, output_s3_bucket=value, output_s3_key_prefix=value, shots=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="braket",
        operation="create_quantum_task",
        op_kwargs={
            "action": action,
            "clientToken": client_token,
            "deviceArn": device_arn,
            "deviceParameters": device_parameters,
            "outputS3Bucket": output_s3_bucket,
            "outputS3KeyPrefix": output_s3_key_prefix,
            "shots": shots,
            "tags": tags,
        },
    )


async def get(hub, ctx, quantum_task_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified quantum task.

    Args:
        quantum_task_arn(str): the ARN of the task to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.braket.quantum_task.get(ctx, quantum_task_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.braket.quantum_task.get quantum_task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="braket",
        operation="get_quantum_task",
        op_kwargs={"quantumTaskArn": quantum_task_arn},
    )


async def search(
    hub, ctx, filters: List, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for tasks that match the specified filter values.

    Args:
        filters(List): Array of SearchQuantumTasksFilter objects.
        max_results(int, optional): Maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned in the response. Use the token returned from the previous request continue results where the previous request ended. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.braket.quantum_task.search(ctx, filters=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.braket.quantum_task.search filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="braket",
        operation="search_quantum_tasks",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, font_stack: str, font_unicode_range: str, map_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves glyphs used to display labels on a map.

    Args:
        font_stack(str): A comma-separated list of fonts to load glyphs from in order of preference. For example, Noto Sans Regular, Arial Unicode. Valid fonts for Esri styles:    VectorEsriDarkGrayCanvas – Ubuntu Medium Italic | Ubuntu Medium | Ubuntu Italic | Ubuntu Regular | Ubuntu Bold    VectorEsriLightGrayCanvas – Ubuntu Italic | Ubuntu Regular | Ubuntu Light | Ubuntu Bold    VectorEsriTopographic – Noto Sans Italic | Noto Sans Regular | Noto Sans Bold | Noto Serif Regular | Roboto Condensed Light Italic    VectorEsriStreets – Arial Regular | Arial Italic | Arial Bold    VectorEsriNavigation – Arial Regular | Arial Italic | Arial Bold    Valid fonts for HERE Technologies styles:     VectorHereBerlin – Fira GO Regular | Fira GO Bold   .
        font_unicode_range(str): A Unicode range of characters to download glyphs for. Each response will contain 256 characters. For example, 0–255 includes all characters from range U+0000 to 00FF. Must be aligned to multiples of 256.
        map_name(str): The map resource associated with the glyph ﬁle.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.map_.glyph.get_all(
                ctx, font_stack=value, font_unicode_range=value, map_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.map_.glyph.get_all font_stack=value, font_unicode_range=value, map_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="get_map_glyphs",
        op_kwargs={
            "FontStack": font_stack,
            "FontUnicodeRange": font_unicode_range,
            "MapName": map_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(
    hub,
    ctx,
    page_id: str,
    accept_type: str,
    accept_code: str,
    contact_channel_id: str = None,
    note: str = None,
    accept_code_validation: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to acknowledge an engagement to a contact channel during an incident.

    Args:
        page_id(str): The Amazon Resource Name (ARN) of the engagement to a contact channel.
        contact_channel_id(str, optional): The ARN of the contact channel. Defaults to None.
        accept_type(str): The type indicates if the page was DELIVERED or READ.
        note(str, optional): Information provided by the user when the user acknowledges the page. Defaults to None.
        accept_code(str): The accept code is a 6-digit code used to acknowledge the page.
        accept_code_validation(str, optional): An optional field that Incident Manager uses to ENFORCE AcceptCode validation when acknowledging an page. Acknowledgement can occur by replying to a page, or when entering the AcceptCode in the console. Enforcing AcceptCode validation causes Incident Manager to verify that the code entered by the user matches the code sent by Incident Manager with the page. Incident Manager can also IGNORE AcceptCode validation. Ignoring AcceptCode validation causes Incident Manager to accept any value entered for the AcceptCode. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.page.init.accept(
                ctx, page_id=value, accept_type=value, accept_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.page.init.accept page_id=value, accept_type=value, accept_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="accept_page",
        op_kwargs={
            "PageId": page_id,
            "ContactChannelId": contact_channel_id,
            "AcceptType": accept_type,
            "Note": note,
            "AcceptCode": accept_code,
            "AcceptCodeValidation": accept_code_validation,
        },
    )


async def describe(hub, ctx, page_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists details of the engagement to a contact channel.

    Args:
        page_id(str): The ID of the engagement to a contact channel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.page.init.describe(ctx, page_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.page.init.describe page_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="describe_page",
        op_kwargs={"PageId": page_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, ecs_cluster_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deregisters a specified Amazon ECS cluster from a stack. For more information, see  Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack or an attached policy that explicitly grants permissions. For more information on user permissions, see https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html.

    Args:
        ecs_cluster_arn(str): The cluster's Amazon Resource Number (ARN).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.ecs_cluster.deregister(ctx, ecs_cluster_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.ecs_cluster.deregister ecs_cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="deregister_ecs_cluster",
        op_kwargs={"EcsClusterArn": ecs_cluster_arn},
    )


async def describe_all(
    hub,
    ctx,
    ecs_cluster_arns: List = None,
    stack_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes Amazon ECS clusters that are registered with a stack. If you specify only a stack ID, you can use the MaxResults and NextToken parameters to paginate the response. However, AWS OpsWorks Stacks currently supports only one cluster per layer, so the result set has a maximum of one element.  Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack or an attached policy that explicitly grants permission. For more information about user permissions, see Managing User Permissions. This call accepts only one resource-identifying parameter.

    Args:
        ecs_cluster_arns(List, optional): A list of ARNs, one for each cluster to be described. Defaults to None.
        stack_id(str, optional): A stack ID. DescribeEcsClusters returns a description of the cluster that is registered with the stack. Defaults to None.
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object'sNextToken parameter value is set to a token. To retrieve the next set of results, call DescribeEcsClusters again and assign that token to the request object's NextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. Defaults to None.
        max_results(int, optional): To receive a paginated response, use this parameter to specify the maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.ecs_cluster.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.ecs_cluster.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_ecs_clusters",
        op_kwargs={
            "EcsClusterArns": ecs_cluster_arns,
            "StackId": stack_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def register(hub, ctx, ecs_cluster_arn: str, stack_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Registers a specified Amazon ECS cluster with a stack. You can register only one cluster with a stack. A cluster can be registered with only one stack. For more information, see  Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack or an attached policy that explicitly grants permissions. For more information on user permissions, see  Managing User Permissions.

    Args:
        ecs_cluster_arn(str): The cluster's ARN.
        stack_id(str): The stack ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.ecs_cluster.register(
                ctx, ecs_cluster_arn=value, stack_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.ecs_cluster.register ecs_cluster_arn=value, stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="register_ecs_cluster",
        op_kwargs={"EcsClusterArn": ecs_cluster_arn, "StackId": stack_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    cache_parameter_group_family: str,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the default engine and system parameter information for the specified cache engine.

    Args:
        cache_parameter_group_family(str): The name of the cache parameter group family. Valid values are: memcached1.4 | memcached1.5 | memcached1.6 | redis2.6 | redis2.8 | redis3.2 | redis4.0 | redis5.0 | redis6.x | .
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: minimum 20; maximum 100. Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.engine_default_parameter.describe_all(
                ctx, cache_parameter_group_family=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.engine_default_parameter.describe_all cache_parameter_group_family=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_engine_default_parameters",
        op_kwargs={
            "CacheParameterGroupFamily": cache_parameter_group_family,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "borrow_license"


async def checkout(
    hub,
    ctx,
    license_arn: str,
    entitlements: List,
    digital_signature_method: str,
    client_token: str,
    node_id: str = None,
    checkout_metadata: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Checks out the specified license for offline use.

    Args:
        license_arn(str): Amazon Resource Name (ARN) of the license. The license must use the borrow consumption configuration.
        entitlements(List): License entitlements. Partial checkouts are not supported.
        digital_signature_method(str): Digital signature method. The possible value is JSON Web Signature (JWS) algorithm PS384. For more information, see RFC 7518 Digital Signature with RSASSA-PSS.
        node_id(str, optional): Node ID. Defaults to None.
        checkout_metadata(List, optional): Information about constraints. Defaults to None.
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.borrow_license_.checkout(
                ctx,
                license_arn=value,
                entitlements=value,
                digital_signature_method=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.borrow_license.checkout license_arn=value, entitlements=value, digital_signature_method=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="checkout_borrow_license",
        op_kwargs={
            "LicenseArn": license_arn,
            "Entitlements": entitlements,
            "DigitalSignatureMethod": digital_signature_method,
            "NodeId": node_id,
            "CheckoutMetadata": checkout_metadata,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    fargate_profile_name: str,
    cluster_name: str,
    pod_execution_role_arn: str,
    subnets: List = None,
    selectors: List = None,
    client_request_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Fargate profile for your Amazon EKS cluster. You must have at least one Fargate profile in a cluster to be able to run pods on Fargate. The Fargate profile allows an administrator to declare which pods run on Fargate and specify which pods run on which Fargate profile. This declaration is done through the profile’s selectors. Each profile can have up to five selectors that contain a namespace and labels. A namespace is required for every selector. The label field consists of multiple optional key-value pairs. Pods that match the selectors are scheduled on Fargate. If a to-be-scheduled pod matches any of the selectors in the Fargate profile, then that pod is run on Fargate. When you create a Fargate profile, you must specify a pod execution role to use with the pods that are scheduled with the profile. This role is added to the cluster's Kubernetes Role Based Access Control (RBAC) for authorization so that the kubelet that is running on the Fargate infrastructure can register with your Amazon EKS cluster so that it can appear in your cluster as a node. The pod execution role also provides IAM permissions to the Fargate infrastructure to allow read access to Amazon ECR image repositories. For more information, see Pod Execution Role in the Amazon EKS User Guide. Fargate profiles are immutable. However, you can create a new updated profile to replace an existing profile and then delete the original after the updated profile has finished creating. If any Fargate profiles in a cluster are in the DELETING status, you must wait for that Fargate profile to finish deleting before you can create any other profiles in that cluster. For more information, see Fargate Profile in the Amazon EKS User Guide.

    Args:
        fargate_profile_name(str): The name of the Fargate profile.
        cluster_name(str): The name of the Amazon EKS cluster to apply the Fargate profile to.
        pod_execution_role_arn(str): The Amazon Resource Name (ARN) of the pod execution role to use for pods that match the selectors in the Fargate profile. The pod execution role allows Fargate infrastructure to register with your cluster as a node, and it provides read access to Amazon ECR image repositories. For more information, see Pod Execution Role in the Amazon EKS User Guide.
        subnets(List, optional): The IDs of subnets to launch your pods into. At this time, pods running on Fargate are not assigned public IP addresses, so only private subnets (with no direct route to an Internet Gateway) are accepted for this parameter. Defaults to None.
        selectors(List, optional): The selectors to match for pods to use this Fargate profile. Each selector must have an associated namespace. Optionally, you can also specify labels for a namespace. You may specify up to five selectors in a Fargate profile. Defaults to None.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        tags(Dict, optional): The metadata to apply to the Fargate profile to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Fargate profile tags do not propagate to any other resources associated with the Fargate profile, such as the pods that are scheduled with it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.fargate_profile.create(
                ctx, fargate_profile_name=value, cluster_name=value, pod_execution_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.fargate_profile.create fargate_profile_name=value, cluster_name=value, pod_execution_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="create_fargate_profile",
        op_kwargs={
            "fargateProfileName": fargate_profile_name,
            "clusterName": cluster_name,
            "podExecutionRoleArn": pod_execution_role_arn,
            "subnets": subnets,
            "selectors": selectors,
            "clientRequestToken": client_request_token,
            "tags": tags,
        },
    )


async def delete(hub, ctx, cluster_name: str, fargate_profile_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Fargate profile. When you delete a Fargate profile, any pods running on Fargate that were created with the profile are deleted. If those pods match another Fargate profile, then they are scheduled on Fargate with that profile. If they no longer match any Fargate profiles, then they are not scheduled on Fargate and they may remain in a pending state. Only one Fargate profile in a cluster can be in the DELETING status at a time. You must wait for a Fargate profile to finish deleting before you can delete any other profiles in that cluster.

    Args:
        cluster_name(str): The name of the Amazon EKS cluster associated with the Fargate profile to delete.
        fargate_profile_name(str): The name of the Fargate profile to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.fargate_profile.delete(
                ctx, cluster_name=value, fargate_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.fargate_profile.delete cluster_name=value, fargate_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="delete_fargate_profile",
        op_kwargs={
            "clusterName": cluster_name,
            "fargateProfileName": fargate_profile_name,
        },
    )


async def describe(hub, ctx, cluster_name: str, fargate_profile_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns descriptive information about an Fargate profile.

    Args:
        cluster_name(str): The name of the Amazon EKS cluster associated with the Fargate profile.
        fargate_profile_name(str): The name of the Fargate profile to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.fargate_profile.describe(
                ctx, cluster_name=value, fargate_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.fargate_profile.describe cluster_name=value, fargate_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="describe_fargate_profile",
        op_kwargs={
            "clusterName": cluster_name,
            "fargateProfileName": fargate_profile_name,
        },
    )


async def list_all(
    hub, ctx, cluster_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Fargate profiles associated with the specified cluster in your Amazon Web Services account in the specified Region.

    Args:
        cluster_name(str): The name of the Amazon EKS cluster that you would like to list Fargate profiles in.
        max_results(int, optional): The maximum number of Fargate profile results returned by ListFargateProfiles in paginated output. When you use this parameter, ListFargateProfiles returns only maxResults results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListFargateProfiles request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListFargateProfiles returns up to 100 results and a nextToken value if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListFargateProfiles request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.fargate_profile.list_all(ctx, cluster_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.fargate_profile.list_all cluster_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="list_fargate_profiles",
        op_kwargs={
            "clusterName": cluster_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified world generator job.

    Args:
        job(str): The Amazon Resource Name (arn) of the world generator job to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.generation_job.cancel(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.generation_job.cancel job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="cancel_world_generation_job",
        op_kwargs={"job": job},
    )


async def create(
    hub,
    ctx,
    template: str,
    world_count: Dict,
    client_request_token: str = None,
    tags: Dict = None,
    world_tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates worlds using the specified template.

    Args:
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        template(str): The Amazon Resource Name (arn) of the world template describing the worlds you want to create.
        world_count(Dict): Information about the world count.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the world generator job. Defaults to None.
        world_tags(Dict, optional): A map that contains tag keys and tag values that are attached to the generated worlds. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.generation_job.create(
                ctx, template=value, world_count=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.generation_job.create template=value, world_count=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_world_generation_job",
        op_kwargs={
            "clientRequestToken": client_request_token,
            "template": template,
            "worldCount": world_count,
            "tags": tags,
            "worldTags": world_tags,
        },
    )


async def describe(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a world generation job.

    Args:
        job(str): The Amazon Resource Name (arn) of the world generation job to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.generation_job.describe(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.generation_job.describe job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_world_generation_job",
        op_kwargs={"job": job},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists world generator jobs.

    Args:
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListWorldGenerationJobsRequest again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListWorldGeneratorJobs only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListWorldGeneratorJobs request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListWorldGeneratorJobs returns up to 100 results and a nextToken value if applicable. . Defaults to None.
        filters(List, optional): Optional filters to limit results. You can use status and templateId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.generation_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.generation_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_world_generation_jobs",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(hub, ctx, image: Dict, summarization_attributes: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Detects Personal Protective Equipment (PPE) worn by people detected in an image. Amazon Rekognition can detect the following types of PPE.   Face cover   Hand cover   Head cover   You pass the input image as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. The image must be either a PNG or JPG formatted file.   DetectProtectiveEquipment detects PPE worn by up to 15 persons detected in an image. For each person detected in the image the API returns an array of body parts (face, head, left-hand, right-hand). For each body part, an array of detected items of PPE is returned, including an indicator of whether or not the PPE covers the body part. The API returns the confidence it has in each detection (person, PPE, body part and body part coverage). It also returns a bounding box (BoundingBox) for each detected person and each detected item of PPE.  You can optionally request a summary of detected PPE items with the SummarizationAttributes input parameter. The summary provides the following information.    The persons detected as wearing all of the types of PPE that you specify.   The persons detected as not wearing all of the types PPE that you specify.   The persons detected where PPE adornment could not be determined.    This is a stateless API operation. That is, the operation does not persist any data. This operation requires permissions to perform the rekognition:DetectProtectiveEquipment action.

    Args:
        image(Dict): The image in which you want to detect PPE on detected persons. The image can be passed as image bytes or you can reference an image stored in an Amazon S3 bucket. .
        summarization_attributes(Dict, optional): An array of PPE types that you want to summarize. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.protective_equipment.detect(ctx, image=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.protective_equipment.detect image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="detect_protective_equipment",
        op_kwargs={"Image": image, "SummarizationAttributes": summarization_attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(
    hub, ctx, reserved_node_id: str, target_reserved_node_offering_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Exchanges a DC1 Reserved Node for a DC2 Reserved Node with no changes to the configuration (term, payment type, or number of nodes) and no additional costs.

    Args:
        reserved_node_id(str): A string representing the node identifier of the DC1 Reserved Node to be exchanged.
        target_reserved_node_offering_id(str): The unique identifier of the DC2 Reserved Node offering to be used for the exchange. You can obtain the value for the parameter by calling GetReservedNodeExchangeOfferings .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.reserved_node.exchange.init.accept(
                ctx, reserved_node_id=value, target_reserved_node_offering_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.reserved_node.exchange.init.accept reserved_node_id=value, target_reserved_node_offering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="accept_reserved_node_exchange",
        op_kwargs={
            "ReservedNodeId": reserved_node_id,
            "TargetReservedNodeOfferingId": target_reserved_node_offering_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, thing_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the thing groups to which the specified thing belongs.

    Args:
        thing_name(str): The thing name.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.group.for_thing.list(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.group.for_thing.list thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_thing_groups_for_thing",
        op_kwargs={
            "thingName": thing_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    thing_name: str = None,
    thing_groups_to_add: List = None,
    thing_groups_to_remove: List = None,
    override_dynamic_groups: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the groups to which the thing belongs.

    Args:
        thing_name(str, optional): The thing whose group memberships will be updated. Defaults to None.
        thing_groups_to_add(List, optional): The groups to which the thing will be added. Defaults to None.
        thing_groups_to_remove(List, optional): The groups from which the thing will be removed. Defaults to None.
        override_dynamic_groups(bool, optional): Override dynamic thing groups with static thing groups when 10-group limit is reached. If a thing belongs to 10 thing groups, and one or more of those groups are dynamic thing groups, adding a thing to a static group removes the thing from the last dynamic group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.group.for_thing.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.group.for_thing.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_thing_groups_for_thing",
        op_kwargs={
            "thingName": thing_name,
            "thingGroupsToAdd": thing_groups_to_add,
            "thingGroupsToRemove": thing_groups_to_remove,
            "overrideDynamicGroups": override_dynamic_groups,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    dataset_name: str,
    name: str,
    recipe_name: str,
    role_arn: str,
    sample: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DataBrew project.

    Args:
        dataset_name(str): The name of an existing dataset to associate this project with.
        name(str): A unique name for the new project. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
        recipe_name(str): The name of an existing recipe to associate with the project.
        sample(Dict, optional): Represents the sample size and sampling type for DataBrew to use for interactive data analysis. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed for this request.
        tags(Dict, optional): Metadata tags to apply to this project. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.project.init.create(
                ctx, dataset_name=value, name=value, recipe_name=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.project.init.create dataset_name=value, name=value, recipe_name=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="create_project",
        op_kwargs={
            "DatasetName": dataset_name,
            "Name": name,
            "RecipeName": recipe_name,
            "Sample": sample,
            "RoleArn": role_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing DataBrew project.

    Args:
        name(str): The name of the project to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.project.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.project.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="delete_project",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the definition of a specific DataBrew project.

    Args:
        name(str): The name of the project to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.project.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.project.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="describe_project",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the DataBrew projects that are defined.

    Args:
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.project.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.project.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="list_projects",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(hub, ctx, role_arn: str, name: str, sample: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the definition of an existing DataBrew project.

    Args:
        sample(Dict, optional): Represents the sample size and sampling type for DataBrew to use for interactive data analysis. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role to be assumed for this request.
        name(str): The name of the project to be updated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.project.init.update(ctx, role_arn=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.project.init.update role_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="update_project",
        op_kwargs={"Sample": sample, "RoleArn": role_arn, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    app_image_config_name: str,
    tags: List = None,
    kernel_gateway_image_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a configuration for running a SageMaker image as a KernelGateway app. The configuration specifies the Amazon Elastic File System (EFS) storage volume on the image, and a list of the kernels in the image.

    Args:
        app_image_config_name(str): The name of the AppImageConfig. Must be unique to your account.
        tags(List, optional): A list of tags to apply to the AppImageConfig. Defaults to None.
        kernel_gateway_image_config(Dict, optional): The KernelGatewayImageConfig. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.image_config.create(
                ctx, app_image_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.image_config.create app_image_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_app_image_config",
        op_kwargs={
            "AppImageConfigName": app_image_config_name,
            "Tags": tags,
            "KernelGatewayImageConfig": kernel_gateway_image_config,
        },
    )


async def delete(hub, ctx, app_image_config_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an AppImageConfig.

    Args:
        app_image_config_name(str): The name of the AppImageConfig to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.image_config.delete(
                ctx, app_image_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.image_config.delete app_image_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_app_image_config",
        op_kwargs={"AppImageConfigName": app_image_config_name},
    )


async def describe(hub, ctx, app_image_config_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an AppImageConfig.

    Args:
        app_image_config_name(str): The name of the AppImageConfig to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.image_config.describe(
                ctx, app_image_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.image_config.describe app_image_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_app_image_config",
        op_kwargs={"AppImageConfigName": app_image_config_name},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
    modified_time_before: str = None,
    modified_time_after: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the AppImageConfigs in your account and their properties. The list can be filtered by creation time or modified time, and whether the AppImageConfig name contains a specified string.

    Args:
        max_results(int, optional): The maximum number of AppImageConfigs to return in the response. The default value is 10. . Defaults to None.
        next_token(str, optional): If the previous call to ListImages didn't return the full set of AppImageConfigs, the call returns a token for getting the next set of AppImageConfigs. Defaults to None.
        name_contains(str, optional): A filter that returns only AppImageConfigs whose name contains the specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only AppImageConfigs created on or before the specified time. Defaults to None.
        creation_time_after(str, optional): A filter that returns only AppImageConfigs created on or after the specified time. Defaults to None.
        modified_time_before(str, optional): A filter that returns only AppImageConfigs modified on or before the specified time. Defaults to None.
        modified_time_after(str, optional): A filter that returns only AppImageConfigs modified on or after the specified time. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order. The default value is Descending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.image_config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.image_config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_app_image_configs",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
            "ModifiedTimeBefore": modified_time_before,
            "ModifiedTimeAfter": modified_time_after,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def update(
    hub, ctx, app_image_config_name: str, kernel_gateway_image_config: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the properties of an AppImageConfig.

    Args:
        app_image_config_name(str): The name of the AppImageConfig to update.
        kernel_gateway_image_config(Dict, optional): The new KernelGateway app to run on the image. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.image_config.update(
                ctx, app_image_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.image_config.update app_image_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_app_image_config",
        op_kwargs={
            "AppImageConfigName": app_image_config_name,
            "KernelGatewayImageConfig": kernel_gateway_image_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, application_name: str, snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of the application's state data.

    Args:
        application_name(str): The name of an existing application.
        snapshot_name(str): An identifier for the application snapshot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.snapshot.create(
                ctx, application_name=value, snapshot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.snapshot.create application_name=value, snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="create_application_snapshot",
        op_kwargs={"ApplicationName": application_name, "SnapshotName": snapshot_name},
    )


async def delete(
    hub,
    ctx,
    application_name: str,
    snapshot_name: str,
    snapshot_creation_timestamp: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a snapshot of application state.

    Args:
        application_name(str): The name of an existing application.
        snapshot_name(str): The identifier for the snapshot delete.
        snapshot_creation_timestamp(str): The creation timestamp of the application snapshot to delete. You can retrieve this value using or .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.snapshot.delete(
                ctx, application_name=value, snapshot_name=value, snapshot_creation_timestamp=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.snapshot.delete application_name=value, snapshot_name=value, snapshot_creation_timestamp=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="delete_application_snapshot",
        op_kwargs={
            "ApplicationName": application_name,
            "SnapshotName": snapshot_name,
            "SnapshotCreationTimestamp": snapshot_creation_timestamp,
        },
    )


async def describe(hub, ctx, application_name: str, snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a snapshot of application state data.

    Args:
        application_name(str): The name of an existing application.
        snapshot_name(str): The identifier of an application snapshot. You can retrieve this value using .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.snapshot.describe(
                ctx, application_name=value, snapshot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.snapshot.describe application_name=value, snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="describe_application_snapshot",
        op_kwargs={"ApplicationName": application_name, "SnapshotName": snapshot_name},
    )


async def list_all(
    hub, ctx, application_name: str, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about the current application snapshots.

    Args:
        application_name(str): The name of an existing application.
        limit(int, optional): The maximum number of application snapshots to list. Defaults to None.
        next_token(str, optional): Use this parameter if you receive a NextToken response in a previous request that indicates that there is more output available. Set it to the value of the previous call's NextToken response to indicate where the output should continue from. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.snapshot.list_all(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.snapshot.list_all application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="list_application_snapshots",
        op_kwargs={
            "ApplicationName": application_name,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    metric_name: str,
    metric_type: str,
    client_request_token: str,
    display_name: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Use this API to define a Custom Metric published by your devices to Device Defender.

    Args:
        metric_name(str):  The name of the custom metric. This will be used in the metric report submitted from the device/thing. Shouldn't begin with aws:. Cannot be updated once defined.
        display_name(str, optional):  Field represents a friendly name in the console for the custom metric; it doesn't have to be unique. Don't use this name as the metric identifier in the device metric report. Can be updated once defined. Defaults to None.
        metric_type(str):  The type of the custom metric. Types include string-list, ip-address-list, number-list, and number. .
        tags(List, optional):  Metadata that can be used to manage the custom metric. . Defaults to None.
        client_request_token(str): Each custom metric must have a unique client request token. If you try to create a new custom metric that already exists with a different token, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.custom_metric.create(
                ctx, metric_name=value, metric_type=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.custom_metric.create metric_name=value, metric_type=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_custom_metric",
        op_kwargs={
            "metricName": metric_name,
            "displayName": display_name,
            "metricType": metric_type,
            "tags": tags,
            "clientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, metric_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Before you can delete a custom metric, you must first remove the custom metric from all security profiles it's a part of. The security profile associated with the custom metric can be found using the ListSecurityProfiles API with metricName set to your custom metric name.   Deletes a Device Defender detect custom metric.

    Args:
        metric_name(str):  The name of the custom metric. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.custom_metric.delete(ctx, metric_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.custom_metric.delete metric_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_custom_metric",
        op_kwargs={"metricName": metric_name},
    )


async def describe(hub, ctx, metric_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets information about a Device Defender detect custom metric.

    Args:
        metric_name(str):  The name of the custom metric. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.custom_metric.describe(ctx, metric_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.custom_metric.describe metric_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_custom_metric",
        op_kwargs={"metricName": metric_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

     Lists your Device Defender detect custom metrics.

    Args:
        next_token(str, optional):  The token for the next set of results. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return at one time. The default is 25. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.custom_metric.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.custom_metric.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_custom_metrics",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(hub, ctx, metric_name: str, display_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Device Defender detect custom metric.

    Args:
        metric_name(str):  The name of the custom metric. Cannot be updated. .
        display_name(str):  Field represents a friendly name in the console for the custom metric, it doesn't have to be unique. Don't use this name as the metric identifier in the device metric report. Can be updated. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.custom_metric.update(
                ctx, metric_name=value, display_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.custom_metric.update metric_name=value, display_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_custom_metric",
        op_kwargs={"metricName": metric_name, "displayName": display_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def remove(hub, ctx, finding_arns: List, attribute_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.

    Args:
        finding_arns(List): The ARNs that specify the findings that you want to remove attributes from.
        attribute_keys(List): The array of attribute keys that you want to remove from specified findings.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.attribute.from_finding.remove(
                ctx, finding_arns=value, attribute_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.attribute.from_finding.remove finding_arns=value, attribute_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="remove_attributes_from_findings",
        op_kwargs={"findingArns": finding_arns, "attributeKeys": attribute_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, include_inactive: bool = None, page_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of available instance images, or blueprints. You can use a blueprint to create a new instance already running a specific operating system, as well as a preinstalled app or development stack. The software each instance is running depends on the blueprint image you choose.  Use active blueprints when creating new instances. Inactive blueprints are listed to support customers with existing instances and are not necessarily available to create new instances. Blueprints are marked inactive when they become outdated due to operating system updates or new application releases.

    Args:
        include_inactive(bool, optional): A Boolean value indicating whether to include inactive results in your request. Defaults to None.
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetBlueprints request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.blueprint.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.blueprint.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_blueprints",
        op_kwargs={"includeInactive": include_inactive, "pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, resource_group_name: str, component_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the monitoring configuration of the component.

    Args:
        resource_group_name(str): The name of the resource group.
        component_name(str): The name of the component.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.configuration.init.describe(
                ctx, resource_group_name=value, component_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.configuration.init.describe resource_group_name=value, component_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="describe_component_configuration",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "ComponentName": component_name,
        },
    )


async def update(
    hub,
    ctx,
    resource_group_name: str,
    component_name: str,
    monitor: bool = None,
    tier: str = None,
    component_configuration: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the monitoring configurations for the component. The configuration input parameter is an escaped JSON of the configuration and should match the schema of what is returned by DescribeComponentConfigurationRecommendation.

    Args:
        resource_group_name(str): The name of the resource group.
        component_name(str): The name of the component.
        monitor(bool, optional): Indicates whether the application component is monitored. Defaults to None.
        tier(str, optional): The tier of the application component. Supported tiers include DOT_NET_WORKER, DOT_NET_WEB, DOT_NET_CORE, SQL_SERVER, and DEFAULT. Defaults to None.
        component_configuration(str, optional): The configuration settings of the component. The value is the escaped JSON of the configuration. For more information about the JSON format, see Working with JSON. You can send a request to DescribeComponentConfigurationRecommendation to see the recommended configuration for a component. For the complete format of the component configuration file, see Component Configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.configuration.init.update(
                ctx, resource_group_name=value, component_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.configuration.init.update resource_group_name=value, component_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="update_component_configuration",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "ComponentName": component_name,
            "Monitor": monitor,
            "Tier": tier,
            "ComponentConfiguration": component_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(hub, ctx, server_name: str, engine_attributes: List = None) -> Dict:
    r"""
    **Autogenerated function**

     Manually starts server maintenance. This command can be useful if an earlier maintenance attempt failed, and the underlying cause of maintenance failure has been resolved. The server is in an UNDER_MAINTENANCE state while maintenance is in progress.   Maintenance can only be started on servers in HEALTHY and UNHEALTHY states. Otherwise, an InvalidStateException is thrown. A ResourceNotFoundException is thrown when the server does not exist. A ValidationException is raised when parameters of the request are not valid.

    Args:
        server_name(str): The name of the server on which to run maintenance. .
        engine_attributes(List, optional): Engine attributes that are specific to the server on which you want to run maintenance.  Attributes accepted in a StartMaintenance request for Chef     CHEF_MAJOR_UPGRADE: If a Chef Automate server is eligible for upgrade to Chef Automate 2, add this engine attribute to a StartMaintenance request and set the value to true to upgrade the server to Chef Automate 2. For more information, see Upgrade an AWS OpsWorks for Chef Automate Server to Chef Automate 2.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.maintenance.start(ctx, server_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.maintenance.start server_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="start_maintenance",
        op_kwargs={"ServerName": server_name, "EngineAttributes": engine_attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def create(
    hub, ctx, resource_id: str, metadata: Dict = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    If you create a new application in Application Manager, Amazon Web Services Systems Manager calls this API operation to specify information about the new application, including the application type.

    Args:
        resource_id(str): A resource ID for a new Application Manager application.
        metadata(Dict, optional): Metadata for a new Application Manager application. . Defaults to None.
        tags(List, optional): Optional metadata that you assign to a resource. You can specify a maximum of five tags for an OpsMetadata object. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag an OpsMetadata object to identify an environment or target Region. In this case, you could specify the following key-value pairs:    Key=Environment,Value=Production     Key=Region,Value=us-east-2   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.metadata.create(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.metadata.create resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="create_ops_metadata",
        op_kwargs={"ResourceId": resource_id, "Metadata": metadata, "Tags": tags},
    )


async def delete(hub, ctx, ops_metadata_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete OpsMetadata related to an application.

    Args:
        ops_metadata_arn(str): The Amazon Resource Name (ARN) of an OpsMetadata Object to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.metadata.delete(ctx, ops_metadata_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.metadata.delete ops_metadata_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_ops_metadata",
        op_kwargs={"OpsMetadataArn": ops_metadata_arn},
    )


async def get(
    hub, ctx, ops_metadata_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    View operational metadata related to an application in Application Manager.

    Args:
        ops_metadata_arn(str): The Amazon Resource Name (ARN) of an OpsMetadata Object to view.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.metadata.get(ctx, ops_metadata_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.metadata.get ops_metadata_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_ops_metadata",
        op_kwargs={
            "OpsMetadataArn": ops_metadata_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def list_(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Amazon Web Services Systems Manager calls this API operation when displaying all Application Manager OpsMetadata objects or blobs.

    Args:
        filters(List, optional): One or more filters to limit the number of OpsMetadata objects returned by the call. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.metadata.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.metadata.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_ops_metadata",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    ops_metadata_arn: str,
    metadata_to_update: Dict = None,
    keys_to_delete: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Amazon Web Services Systems Manager calls this API operation when you edit OpsMetadata in Application Manager.

    Args:
        ops_metadata_arn(str): The Amazon Resoure Name (ARN) of the OpsMetadata Object to update.
        metadata_to_update(Dict, optional): Metadata to add to an OpsMetadata object. Defaults to None.
        keys_to_delete(List, optional): The metadata keys to delete from the OpsMetadata object. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.metadata.update(ctx, ops_metadata_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.metadata.update ops_metadata_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_ops_metadata",
        op_kwargs={
            "OpsMetadataArn": ops_metadata_arn,
            "MetadataToUpdate": metadata_to_update,
            "KeysToDelete": keys_to_delete,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, names: List, include_graph: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of resource metadata for a given list of workflow names. After calling the ListWorkflows operation, you can call this operation to access the data to which you have been granted permissions. This operation supports all IAM permissions, including permission conditions that uses tags.

    Args:
        names(List): A list of workflow names, which may be the names returned from the ListWorkflows operation.
        include_graph(bool, optional): Specifies whether to include a graph when returning the workflow resource metadata. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.get.workflow.batch(ctx, names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.get.workflow.batch names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="batch_get_workflows",
        op_kwargs={"Names": names, "IncludeGraph": include_graph},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    operating_system: str = None,
    global_filters: Dict = None,
    approval_rules: Dict = None,
    approved_patches: List = None,
    approved_patches_compliance_level: str = None,
    approved_patches_enable_non_security: bool = None,
    rejected_patches: List = None,
    rejected_patches_action: str = None,
    description: str = None,
    sources: List = None,
    client_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a patch baseline.  For information about valid key-value pairs in PatchFilters for each supported operating system type, see PatchFilter.

    Args:
        operating_system(str, optional): Defines the operating system the patch baseline applies to. The default value is WINDOWS. Defaults to None.
        name(str): The name of the patch baseline.
        global_filters(Dict, optional): A set of global filters used to include patches in the baseline. Defaults to None.
        approval_rules(Dict, optional): A set of rules used to include patches in the baseline. Defaults to None.
        approved_patches(List, optional): A list of explicitly approved patches for the baseline. For information about accepted formats for lists of approved patches and rejected patches, see About package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        approved_patches_compliance_level(str, optional): Defines the compliance level for approved patches. When an approved patch is reported as missing, this value describes the severity of the compliance violation. The default value is UNSPECIFIED. Defaults to None.
        approved_patches_enable_non_security(bool, optional): Indicates whether the list of approved patches includes non-security updates that should be applied to the instances. The default value is false. Applies to Linux instances only. Defaults to None.
        rejected_patches(List, optional): A list of explicitly rejected patches for the baseline. For information about accepted formats for lists of approved patches and rejected patches, see About package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        rejected_patches_action(str, optional): The action for Patch Manager to take on patches included in the RejectedPackages list.     ALLOW_AS_DEPENDENCY : A package in the Rejected patches list is installed only if it is a dependency of another package. It is considered compliant with the patch baseline, and its status is reported as InstalledOther. This is the default action if no option is specified.     BLOCK : Packages in the RejectedPatches list, and packages that include them as dependencies, aren't installed under any circumstances. If a package was installed before it was added to the Rejected patches list, it is considered non-compliant with the patch baseline, and its status is reported as InstalledRejected.  . Defaults to None.
        description(str, optional): A description of the patch baseline. Defaults to None.
        sources(List, optional): Information about the patches to use to update the instances, including target operating systems and source repositories. Applies to Linux instances only. Defaults to None.
        client_token(str, optional): User-provided idempotency token. Defaults to None.
        tags(List, optional): Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag a patch baseline to identify the severity level of patches it specifies and the operating system family it applies to. In this case, you could specify the following key-value pairs:    Key=PatchSeverity,Value=Critical     Key=OS,Value=Windows     To add tags to an existing patch baseline, use the AddTagsToResource operation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.baseline.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.baseline.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="create_patch_baseline",
        op_kwargs={
            "OperatingSystem": operating_system,
            "Name": name,
            "GlobalFilters": global_filters,
            "ApprovalRules": approval_rules,
            "ApprovedPatches": approved_patches,
            "ApprovedPatchesComplianceLevel": approved_patches_compliance_level,
            "ApprovedPatchesEnableNonSecurity": approved_patches_enable_non_security,
            "RejectedPatches": rejected_patches,
            "RejectedPatchesAction": rejected_patches_action,
            "Description": description,
            "Sources": sources,
            "ClientToken": client_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, baseline_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a patch baseline.

    Args:
        baseline_id(str): The ID of the patch baseline to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.baseline.init.delete(ctx, baseline_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.baseline.init.delete baseline_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_patch_baseline",
        op_kwargs={"BaselineId": baseline_id},
    )


async def describe_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the patch baselines in your account.

    Args:
        filters(List, optional): Each element in the array is a structure containing a key-value pair. Supported keys for DescribePatchBaselines include the following:     NAME_PREFIX   Sample values: AWS- | My-      OWNER   Sample values: AWS | Self      OPERATING_SYSTEM   Sample values: AMAZON_LINUX | SUSE | WINDOWS   . Defaults to None.
        max_results(int, optional): The maximum number of patch baselines to return (per page). Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.baseline.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.baseline.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_patch_baselines",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(hub, ctx, baseline_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a patch baseline.

    Args:
        baseline_id(str): The ID of the patch baseline to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.baseline.init.get(ctx, baseline_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.baseline.init.get baseline_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_patch_baseline",
        op_kwargs={"BaselineId": baseline_id},
    )


async def update(
    hub,
    ctx,
    baseline_id: str,
    name: str = None,
    global_filters: Dict = None,
    approval_rules: Dict = None,
    approved_patches: List = None,
    approved_patches_compliance_level: str = None,
    approved_patches_enable_non_security: bool = None,
    rejected_patches: List = None,
    rejected_patches_action: str = None,
    description: str = None,
    sources: List = None,
    replace: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing patch baseline. Fields not specified in the request are left unchanged.  For information about valid key-value pairs in PatchFilters for each supported operating system type, see PatchFilter.

    Args:
        baseline_id(str): The ID of the patch baseline to update.
        name(str, optional): The name of the patch baseline. Defaults to None.
        global_filters(Dict, optional): A set of global filters used to include patches in the baseline. Defaults to None.
        approval_rules(Dict, optional): A set of rules used to include patches in the baseline. Defaults to None.
        approved_patches(List, optional): A list of explicitly approved patches for the baseline. For information about accepted formats for lists of approved patches and rejected patches, see About package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        approved_patches_compliance_level(str, optional): Assigns a new compliance severity level to an existing patch baseline. Defaults to None.
        approved_patches_enable_non_security(bool, optional): Indicates whether the list of approved patches includes non-security updates that should be applied to the instances. The default value is false. Applies to Linux instances only. Defaults to None.
        rejected_patches(List, optional): A list of explicitly rejected patches for the baseline. For information about accepted formats for lists of approved patches and rejected patches, see About package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        rejected_patches_action(str, optional): The action for Patch Manager to take on patches included in the RejectedPackages list.     ALLOW_AS_DEPENDENCY : A package in the Rejected patches list is installed only if it is a dependency of another package. It is considered compliant with the patch baseline, and its status is reported as InstalledOther. This is the default action if no option is specified.     BLOCK : Packages in the RejectedPatches list, and packages that include them as dependencies, aren't installed under any circumstances. If a package was installed before it was added to the Rejected patches list, it is considered non-compliant with the patch baseline, and its status is reported as InstalledRejected.  . Defaults to None.
        description(str, optional): A description of the patch baseline. Defaults to None.
        sources(List, optional): Information about the patches to use to update the instances, including target operating systems and source repositories. Applies to Linux instances only. Defaults to None.
        replace(bool, optional): If True, then all fields that are required by the CreatePatchBaseline operation are also required for this API request. Optional fields that aren't specified are set to null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.baseline.init.update(ctx, baseline_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.baseline.init.update baseline_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_patch_baseline",
        op_kwargs={
            "BaselineId": baseline_id,
            "Name": name,
            "GlobalFilters": global_filters,
            "ApprovalRules": approval_rules,
            "ApprovedPatches": approved_patches,
            "ApprovedPatchesComplianceLevel": approved_patches_compliance_level,
            "ApprovedPatchesEnableNonSecurity": approved_patches_enable_non_security,
            "RejectedPatches": rejected_patches,
            "RejectedPatchesAction": rejected_patches_action,
            "Description": description,
            "Sources": sources,
            "Replace": replace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    service_id: str,
    instances: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the current health status (Healthy, Unhealthy, or Unknown) of one or more instances that are associated with a specified service.  There's a brief delay between when you register an instance and when the health status for the instance is available.

    Args:
        service_id(str): The ID of the service that the instance is associated with.
        instances(List, optional): An array that contains the IDs of all the instances that you want to get the health status for. If you omit Instances, Cloud Map returns the health status for all the instances that are associated with the specified service.  To get the IDs for the instances that you've registered by using a specified service, submit a ListInstances request. . Defaults to None.
        max_results(int, optional): The maximum number of instances that you want Cloud Map to return in the response to a GetInstancesHealthStatus request. If you don't specify a value for MaxResults, Cloud Map returns up to 100 instances. Defaults to None.
        next_token(str, optional): For the first GetInstancesHealthStatus request, omit this value. If more than MaxResults instances match the specified criteria, you can submit another GetInstancesHealthStatus request to get the next group of results. Specify the value of NextToken from the previous response in the next request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.instance.health_status.get(
                ctx, service_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.instance.health_status.get service_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="get_instances_health_status",
        op_kwargs={
            "ServiceId": service_id,
            "Instances": instances,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    product_id: str,
    parameters: Dict,
    idempotency_token: str,
    accept_language: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a provisioning artifact (also known as a version) for the specified product. You cannot create a provisioning artifact for a product that was shared with you. The user or role that performs this operation must have the cloudformation:GetTemplate IAM policy permission. This policy permission is required when using the ImportFromPhysicalId template source in the information data section.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        product_id(str): The product identifier.
        parameters(Dict): The configuration for the provisioning artifact.
        idempotency_token(str): A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioning.artifact.init.create(
                ctx, product_id=value, parameters=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioning.artifact.init.create product_id=value, parameters=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_provisioning_artifact",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProductId": product_id,
            "Parameters": parameters,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(
    hub,
    ctx,
    product_id: str,
    provisioning_artifact_id: str,
    accept_language: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified provisioning artifact (also known as a version) for the specified product. You cannot delete a provisioning artifact associated with a product that was shared with you. You cannot delete the last provisioning artifact for a product, because a product must have at least one provisioning artifact.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        product_id(str): The product identifier.
        provisioning_artifact_id(str): The identifier of the provisioning artifact.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioning.artifact.init.delete(
                ctx, product_id=value, provisioning_artifact_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioning.artifact.init.delete product_id=value, provisioning_artifact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_provisioning_artifact",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProductId": product_id,
            "ProvisioningArtifactId": provisioning_artifact_id,
        },
    )


async def describe(
    hub,
    ctx,
    accept_language: str = None,
    provisioning_artifact_id: str = None,
    product_id: str = None,
    provisioning_artifact_name: str = None,
    product_name: str = None,
    verbose: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified provisioning artifact (also known as a version) for the specified product.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        provisioning_artifact_id(str, optional): The identifier of the provisioning artifact. Defaults to None.
        product_id(str, optional): The product identifier. Defaults to None.
        provisioning_artifact_name(str, optional): The provisioning artifact name. Defaults to None.
        product_name(str, optional): The product name. Defaults to None.
        verbose(bool, optional): Indicates whether a verbose level of detail is enabled. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioning.artifact.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioning.artifact.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_provisioning_artifact",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProvisioningArtifactId": provisioning_artifact_id,
            "ProductId": product_id,
            "ProvisioningArtifactName": provisioning_artifact_name,
            "ProductName": product_name,
            "Verbose": verbose,
        },
    )


async def list_all(hub, ctx, product_id: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all provisioning artifacts (also known as versions) for the specified product.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        product_id(str): The product identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioning.artifact.init.list_all(
                ctx, product_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioning.artifact.init.list_all product_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="list_provisioning_artifacts",
        op_kwargs={"AcceptLanguage": accept_language, "ProductId": product_id},
    )


async def update(
    hub,
    ctx,
    product_id: str,
    provisioning_artifact_id: str,
    accept_language: str = None,
    name: str = None,
    description: str = None,
    active: bool = None,
    guidance: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified provisioning artifact (also known as a version) for the specified product. You cannot update a provisioning artifact for a product that was shared with you.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        product_id(str): The product identifier.
        provisioning_artifact_id(str): The identifier of the provisioning artifact.
        name(str, optional): The updated name of the provisioning artifact. Defaults to None.
        description(str, optional): The updated description of the provisioning artifact. Defaults to None.
        active(bool, optional): Indicates whether the product version is active. Inactive provisioning artifacts are invisible to end users. End users cannot launch or update a provisioned product from an inactive provisioning artifact. Defaults to None.
        guidance(str, optional): Information set by the administrator to provide guidance to end users about which provisioning artifacts to use. The DEFAULT value indicates that the product version is active. The administrator can set the guidance to DEPRECATED to inform users that the product version is deprecated. Users are able to make updates to a provisioned product of a deprecated version but cannot launch new provisioned products using a deprecated version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioning.artifact.init.update(
                ctx, product_id=value, provisioning_artifact_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioning.artifact.init.update product_id=value, provisioning_artifact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_provisioning_artifact",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProductId": product_id,
            "ProvisioningArtifactId": provisioning_artifact_id,
            "Name": name,
            "Description": description,
            "Active": active,
            "Guidance": guidance,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, gateway_arn: str, bandwidth_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the bandwidth rate limits of a gateway. You can delete either the upload and download bandwidth rate limit, or you can delete both. If you delete only one of the limits, the other limit remains unchanged. To specify which gateway to work with, use the Amazon Resource Name (ARN) of the gateway in your request. This operation is supported for the stored volume, cached volume and tape gateway types.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        bandwidth_type(str): One of the BandwidthType values that indicates the gateway bandwidth rate limit to delete. Valid Values: UPLOAD | DOWNLOAD | ALL .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.bandwidth_rate_limit.init.delete(
                ctx, gateway_arn=value, bandwidth_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.bandwidth_rate_limit.init.delete gateway_arn=value, bandwidth_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_bandwidth_rate_limit",
        op_kwargs={"GatewayARN": gateway_arn, "BandwidthType": bandwidth_type},
    )


async def describe(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the bandwidth rate limits of a gateway. By default, these limits are not set, which means no bandwidth rate limiting is in effect. This operation is supported for the stored volume, cached volume, and tape gateway types. This operation only returns a value for a bandwidth rate limit only if the limit is set. If no limits are set for the gateway, then this operation returns only the gateway ARN in the response body. To specify which gateway to describe, use the Amazon Resource Name (ARN) of the gateway in your request.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.bandwidth_rate_limit.init.describe(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.bandwidth_rate_limit.init.describe gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_bandwidth_rate_limit",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def update(
    hub,
    ctx,
    gateway_arn: str,
    average_upload_rate_limit_in_bits_per_sec: int = None,
    average_download_rate_limit_in_bits_per_sec: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the bandwidth rate limits of a gateway. You can update both the upload and download bandwidth rate limit or specify only one of the two. If you don't set a bandwidth rate limit, the existing rate limit remains. This operation is supported for the stored volume, cached volume, and tape gateway types. By default, a gateway's bandwidth rate limits are not set. If you don't set any limit, the gateway does not have any limitations on its bandwidth usage and could potentially use the maximum available bandwidth. To specify which gateway to update, use the Amazon Resource Name (ARN) of the gateway in your request.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        average_upload_rate_limit_in_bits_per_sec(int, optional): The average upload bandwidth rate limit in bits per second. Defaults to None.
        average_download_rate_limit_in_bits_per_sec(int, optional): The average download bandwidth rate limit in bits per second. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.bandwidth_rate_limit.init.update(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.bandwidth_rate_limit.init.update gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_bandwidth_rate_limit",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "AverageUploadRateLimitInBitsPerSec": average_upload_rate_limit_in_bits_per_sec,
            "AverageDownloadRateLimitInBitsPerSec": average_download_rate_limit_in_bits_per_sec,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    email: str,
    account_name: str,
    role_name: str = None,
    iam_user_access_to_billing: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This action is available if all of the following are true:   You're authorized to create accounts in the AWS GovCloud (US) Region. For more information on the AWS GovCloud (US) Region, see the  AWS GovCloud User Guide.    You already have an account in the AWS GovCloud (US) Region that is paired with a management account of an organization in the commercial Region.   You call this action from the management account of your organization in the commercial Region.   You have the organizations:CreateGovCloudAccount permission.    AWS Organizations automatically creates the required service-linked role named AWSServiceRoleForOrganizations. For more information, see AWS Organizations and Service-Linked Roles in the AWS Organizations User Guide.  AWS automatically enables AWS CloudTrail for AWS GovCloud (US) accounts, but you should also do the following:   Verify that AWS CloudTrail is enabled to store logs.   Create an S3 bucket for AWS CloudTrail log storage. For more information, see Verifying AWS CloudTrail Is Enabled in the AWS GovCloud User Guide.    If the request includes tags, then the requester must have the organizations:TagResource permission. The tags are attached to the commercial account associated with the GovCloud account, rather than the GovCloud account itself. To add tags to the GovCloud account, call the TagResource operation in the GovCloud Region after the new GovCloud account exists. You call this action from the management account of your organization in the commercial Region to create a standalone AWS account in the AWS GovCloud (US) Region. After the account is created, the management account of an organization in the AWS GovCloud (US) Region can invite it to that organization. For more information on inviting standalone accounts in the AWS GovCloud (US) to join an organization, see AWS Organizations in the AWS GovCloud User Guide.  Calling CreateGovCloudAccount is an asynchronous request that AWS performs in the background. Because CreateGovCloudAccount operates asynchronously, it can return a successful completion message even though account initialization might still be in progress. You might need to wait a few minutes before you can successfully access the account. To check the status of the request, do one of the following:   Use the OperationId response element from this operation to provide as a parameter to the DescribeCreateAccountStatus operation.   Check the AWS CloudTrail log for the CreateAccountResult event. For information on using AWS CloudTrail with Organizations, see Monitoring the Activity in Your Organization in the AWS Organizations User Guide.     When you call the CreateGovCloudAccount action, you create two accounts: a standalone account in the AWS GovCloud (US) Region and an associated account in the commercial Region for billing and support purposes. The account in the commercial Region is automatically a member of the organization whose credentials made the request. Both accounts are associated with the same email address. A role is created in the new account in the commercial Region that allows the management account in the organization in the commercial Region to assume it. An AWS GovCloud (US) account is then created and associated with the commercial account that you just created. A role is also created in the new AWS GovCloud (US) account that can be assumed by the AWS GovCloud (US) account that is associated with the management account of the commercial organization. For more information and to view a diagram that explains how account access works, see AWS Organizations in the AWS GovCloud User Guide.  For more information about creating accounts, see Creating an AWS Account in Your Organization in the AWS Organizations User Guide.     When you create an account in an organization using the AWS Organizations console, API, or CLI commands, the information required for the account to operate as a standalone account is not automatically collected. This includes a payment method and signing the end user license agreement (EULA). If you must remove an account from your organization later, you can do so only after you provide the missing information. Follow the steps at  To leave an organization as a member account in the AWS Organizations User Guide.    If you get an exception that indicates that you exceeded your account limits for the organization, contact AWS Support.   If you get an exception that indicates that the operation failed because your organization is still initializing, wait one hour and then try again. If the error persists, contact AWS Support.   Using CreateGovCloudAccount to create multiple temporary accounts isn't recommended. You can only close an account from the AWS Billing and Cost Management console, and you must be signed in as the root user. For information on the requirements and process for closing an account, see Closing an AWS Account in the AWS Organizations User Guide.     When you create a member account with this operation, you can choose whether to create the account with the IAM User and Role Access to Billing Information switch enabled. If you enable it, IAM users and roles that have appropriate permissions can view billing information for the account. If you disable it, only the account root user can access billing information. For information about how to disable this switch for an account, see Granting Access to Your Billing Information and Tools.

    Args:
        email(str): The email address of the owner to assign to the new member account in the commercial Region. This email address must not already be associated with another AWS account. You must use a valid email address to complete account creation. You can't access the root user of the account or remove an account that was created with an invalid email address. Like all request parameters for CreateGovCloudAccount, the request for the email address for the AWS GovCloud (US) account originates from the commercial Region, not from the AWS GovCloud (US) Region.
        account_name(str): The friendly name of the member account.
        role_name(str, optional): (Optional) The name of an IAM role that AWS Organizations automatically preconfigures in the new member accounts in both the AWS GovCloud (US) Region and in the commercial Region. This role trusts the management account, allowing users in the management account to assume the role, as permitted by the management account administrator. The role has administrator permissions in the new member account. If you don't specify this parameter, the role name defaults to OrganizationAccountAccessRole. For more information about how to use this role to access the member account, see Accessing and Administering the Member Accounts in Your Organization in the AWS Organizations User Guide and steps 2 and 3 in Tutorial: Delegate Access Across AWS Accounts Using IAM Roles in the IAM User Guide.  The regex pattern that is used to validate this parameter. The pattern can include uppercase letters, lowercase letters, digits with no spaces, and any of the following characters: =,.@-. Defaults to None.
        iam_user_access_to_billing(str, optional): If set to ALLOW, the new linked account in the commercial Region enables IAM users to access account billing information if they have the required permissions. If set to DENY, only the root user of the new account can access account billing information. For more information, see Activating Access to the Billing and Cost Management Console in the AWS Billing and Cost Management User Guide.  If you don't specify this parameter, the value defaults to ALLOW, and IAM users and roles with the required permissions can access billing information for the new account. Defaults to None.
        tags(List, optional): A list of tags that you want to attach to the newly created account. These tags are attached to the commercial account associated with the GovCloud account, and not to the GovCloud account itself. To add tags to the actual GovCloud account, call the TagResource operation in the GovCloud region after the new GovCloud account exists. For each tag in the list, you must specify both a tag key and a value. You can set the value to an empty string, but you can't set it to null. For more information about tagging, see Tagging AWS Organizations resources in the AWS Organizations User Guide.  If any one of the tags is invalid or if you exceed the allowed number of tags for an account, then the entire request fails and the account is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.gov_cloud_account.create(
                ctx, email=value, account_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.gov_cloud_account.create email=value, account_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="create_gov_cloud_account",
        op_kwargs={
            "Email": email,
            "AccountName": account_name,
            "RoleName": role_name,
            "IamUserAccessToBilling": iam_user_access_to_billing,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(hub, ctx, config_rule_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the evaluation results for the specified AWS Config rule. You can specify one AWS Config rule per request. After you delete the evaluation results, you can call the StartConfigRulesEvaluation API to start evaluating your AWS resources against the rule.

    Args:
        config_rule_name(str): The name of the AWS Config rule for which you want to delete the evaluation results.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.evaluation.result.delete_multiple(
                ctx, config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.evaluation.result.delete_multiple config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_evaluation_results",
        op_kwargs={"ConfigRuleName": config_rule_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def create(hub, ctx, key_pair_name: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an SSH key pair. The create key pair operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        key_pair_name(str): The name for your new key pair.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.key_pair.create(ctx, key_pair_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.key_pair.create key_pair_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_key_pair",
        op_kwargs={"keyPairName": key_pair_name, "tags": tags},
    )


async def delete(hub, ctx, key_pair_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specific SSH key pair. The delete key pair operation supports tag-based access control via resource tags applied to the resource identified by key pair name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        key_pair_name(str): The name of the key pair to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.key_pair.delete(ctx, key_pair_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.key_pair.delete key_pair_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_key_pair",
        op_kwargs={"keyPairName": key_pair_name},
    )


async def get(hub, ctx, key_pair_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific key pair.

    Args:
        key_pair_name(str): The name of the key pair for which you are requesting information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.key_pair.get(ctx, key_pair_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.key_pair.get key_pair_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_key_pair",
        op_kwargs={"keyPairName": key_pair_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all key pairs in the user's account.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetKeyPairs request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.key_pair.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.key_pair.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_key_pairs",
        op_kwargs={"pageToken": page_token},
    )


async def import_(hub, ctx, key_pair_name: str, public_key_base64: str) -> Dict:
    r"""
    **Autogenerated function**

    Imports a public SSH key from a specific key pair.

    Args:
        key_pair_name(str): The name of the key pair for which you want to import the public key.
        public_key_base64(str): A base64-encoded public key of the ssh-rsa type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.key_pair.import(ctx, key_pair_name=value, public_key_base64=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.key_pair.import key_pair_name=value, public_key_base64=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="import_key_pair",
        op_kwargs={"keyPairName": key_pair_name, "publicKeyBase64": public_key_base64},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, resolver_query_log_config_association_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC. When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC.

    Args:
        resolver_query_log_config_association_id(str): The ID of the Resolver query logging configuration association that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.association.get(
                ctx, resolver_query_log_config_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.association.get resolver_query_log_config_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_query_log_config_association",
        op_kwargs={
            "ResolverQueryLogConfigAssociationId": resolver_query_log_config_association_id
        },
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about associations between Amazon VPCs and query logging configurations.

    Args:
        max_results(int, optional): The maximum number of query logging associations that you want to return in the response to a ListResolverQueryLogConfigAssociations request. If you don't specify a value for MaxResults, Resolver returns up to 100 query logging associations. . Defaults to None.
        next_token(str, optional): For the first ListResolverQueryLogConfigAssociations request, omit this value. If there are more than MaxResults query logging associations that match the values that you specify for Filters, you can submit another ListResolverQueryLogConfigAssociations request to get the next group of associations. In the next request, specify the value of NextToken from the previous response. . Defaults to None.
        filters(List, optional): An optional specification to return a subset of query logging associations.  If you submit a second or subsequent ListResolverQueryLogConfigAssociations request and specify the NextToken parameter, you must use the same values for Filters, if any, as in the previous request. . Defaults to None.
        sort_by(str, optional): The element that you want Resolver to sort query logging associations by.   If you submit a second or subsequent ListResolverQueryLogConfigAssociations request and specify the NextToken parameter, you must use the same value for SortBy, if any, as in the previous request.  Valid values include the following elements:    CreationTime: The ID of the query logging association.    Error: If the value of Status is FAILED, the value of Error indicates the cause:     DESTINATION_NOT_FOUND: The specified destination (for example, an Amazon S3 bucket) was deleted.    ACCESS_DENIED: Permissions don't allow sending logs to the destination.   If Status is a value other than FAILED, ERROR is null.    Id: The ID of the query logging association    ResolverQueryLogConfigId: The ID of the query logging configuration    ResourceId: The ID of the VPC that is associated with the query logging configuration    Status: The current status of the configuration. Valid values include the following:    CREATING: Resolver is creating an association between an Amazon VPC and a query logging configuration.    CREATED: The association between an Amazon VPC and a query logging configuration was successfully created. Resolver is logging queries that originate in the specified VPC.    DELETING: Resolver is deleting this query logging association.    FAILED: Resolver either couldn't create or couldn't delete the query logging association. Here are two common causes:   The specified destination (for example, an Amazon S3 bucket) was deleted.   Permissions don't allow sending logs to the destination.      . Defaults to None.
        sort_order(str, optional): If you specified a value for SortBy, the order that you want query logging associations to be listed in, ASCENDING or DESCENDING.  If you submit a second or subsequent ListResolverQueryLogConfigAssociations request and specify the NextToken parameter, you must use the same value for SortOrder, if any, as in the previous request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.association.list_all(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.association.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_resolver_query_log_config_associations",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, organization_id: str, user_id: str, mailbox_quota: int
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a user's current mailbox quota for a specified organization and user.

    Args:
        organization_id(str): The identifier for the organization that contains the user for whom to update the mailbox quota.
        user_id(str): The identifer for the user for whom to update the mailbox quota.
        mailbox_quota(int): The updated mailbox quota, in MB, for the specified user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.quota.update(
                ctx, organization_id=value, user_id=value, mailbox_quota=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.quota.update organization_id=value, user_id=value, mailbox_quota=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="update_mailbox_quota",
        op_kwargs={
            "OrganizationId": organization_id,
            "UserId": user_id,
            "MailboxQuota": mailbox_quota,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def add(
    hub, ctx, topic_arn: str, label: str, aws_account_id: List, action_name: List
) -> None:
    r"""
    **Autogenerated function**

    Adds a statement to a topic's access control policy, granting access for the specified accounts to the specified actions.

    Args:
        topic_arn(str): The ARN of the topic whose access control policy you wish to modify.
        label(str): A unique identifier for the new policy statement.
        aws_account_id(List): The account IDs of the users (principals) who will be given access to the specified actions. The users must have account, but do not need to be signed up for this service.
        action_name(List): The action you want to allow for the specified principal(s). Valid values: Any Amazon SNS action name, for example Publish.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.permission.add(
                ctx, topic_arn=value, label=value, aws_account_id=value, action_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.permission.add topic_arn=value, label=value, aws_account_id=value, action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="add_permission",
        op_kwargs={
            "TopicArn": topic_arn,
            "Label": label,
            "AWSAccountId": aws_account_id,
            "ActionName": action_name,
        },
    )


async def remove(hub, ctx, topic_arn: str, label: str) -> None:
    r"""
    **Autogenerated function**

    Removes a statement from a topic's access control policy.

    Args:
        topic_arn(str): The ARN of the topic whose access control policy you wish to modify.
        label(str): The unique label of the statement you want to remove.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.permission.remove(ctx, topic_arn=value, label=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.permission.remove topic_arn=value, label=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="remove_permission",
        op_kwargs={"TopicArn": topic_arn, "Label": label},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, thing_name: str, entity_id: str, namespace_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a device with a concrete thing that is in the user's registry. A thing can be associated with only one device at a time. If you associate a thing with a new device id, its previous association will be removed.

    Args:
        thing_name(str): The name of the thing to which the entity is to be associated.
        entity_id(str): The ID of the device to be associated with the thing. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME .
        namespace_version(int, optional): The version of the user's namespace. Defaults to the latest version of the user's namespace. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.entity.to_thing.associate(
                ctx, thing_name=value, entity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.entity.to_thing.associate thing_name=value, entity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="associate_entity_to_thing",
        op_kwargs={
            "thingName": thing_name,
            "entityId": entity_id,
            "namespaceVersion": namespace_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, identifiers: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a set of cluster snapshots.

    Args:
        identifiers(List): A list of identifiers for the snapshots that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.delete_cluster_snapshot.batch(ctx, identifiers=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.delete_cluster_snapshot.batch identifiers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="batch_delete_cluster_snapshots",
        op_kwargs={"Identifiers": identifiers},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, resource_identifier: str, resource_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Fetches the log-level override, if any, for a given resource-ID and resource-type. It can be used for a wireless device or a wireless gateway.

    Args:
        resource_identifier(str): The identifier of the resource. For a Wireless Device, it is the wireless device ID. For a wireless gateway, it is the wireless gateway ID.
        resource_type(str): The type of the resource, which can be WirelessDevice or WirelessGateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.resource.log_level.get(
                ctx, resource_identifier=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.resource.log_level.get resource_identifier=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_resource_log_level",
        op_kwargs={
            "ResourceIdentifier": resource_identifier,
            "ResourceType": resource_type,
        },
    )


async def put(
    hub, ctx, resource_identifier: str, resource_type: str, log_level: str
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the log-level override for a resource-ID and resource-type. This option can be specified for a wireless gateway or a wireless device. A limit of 200 log level override can be set per account.

    Args:
        resource_identifier(str): The identifier of the resource. For a Wireless Device, it is the wireless device ID. For a wireless gateway, it is the wireless gateway ID.
        resource_type(str): The type of the resource, which can be WirelessDevice or WirelessGateway.
        log_level(str): The log level for a log message.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.resource.log_level.put(
                ctx, resource_identifier=value, resource_type=value, log_level=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.resource.log_level.put resource_identifier=value, resource_type=value, log_level=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="put_resource_log_level",
        op_kwargs={
            "ResourceIdentifier": resource_identifier,
            "ResourceType": resource_type,
            "LogLevel": log_level,
        },
    )


async def reset(hub, ctx, resource_identifier: str, resource_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the log-level override, if any, for a specific resource-ID and resource-type. It can be used for a wireless device or a wireless gateway.

    Args:
        resource_identifier(str): The identifier of the resource. For a Wireless Device, it is the wireless device ID. For a wireless gateway, it is the wireless gateway ID.
        resource_type(str): The type of the resource, which can be WirelessDevice or WirelessGateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.resource.log_level.reset(
                ctx, resource_identifier=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.resource.log_level.reset resource_identifier=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="reset_resource_log_level",
        op_kwargs={
            "ResourceIdentifier": resource_identifier,
            "ResourceType": resource_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "adjustment_type"


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Describes the available adjustment types for step scaling and simple scaling policies. The following adjustment types are supported:    ChangeInCapacity     ExactCapacity     PercentChangeInCapacity


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.adjustment_type_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.adjustment_type.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_adjustment_types",
        op_kwargs={},
    )
